# RuntimeEnvironment

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**hardware** | **object** | Hardware configuration used. | [optional]
**operating_system** | **object** | Operating system used. | [optional]
**python_version** | **str** | Python version on which the application runs on. | [optional]
**cuda_version** | **str** | Nvidia CUDA version which the application uses. | [optional]
**platform** | **str** | Platform used - corresponds to sysconfig.get_platform() call. | [optional]
**name** | **str** | User defined name of the runtime environment. | [optional]
**ipython** | **object** | Additional information captured when recommendations were requested for Jupyter Notebook environments.  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
